@@ -1,7 +1,7 @@
 import inspect
 import traceback
 from aiohttp import web
-from cowait.types import typed_async_call, get_return_type
+from cowait.types import typed_async_call
 
 RPC_CALL = 'rpc/call'
 RPC_ERROR = 'rpc/error'
@@ -15,10 +15,10 @@ class RpcComponent():
 
         # listen for websocket rpc
         task.node.parent.on(RPC_CALL, self.on_rpc)
-        task.node.children.on(RPC_CALL, self.on_rpc)
+        task.node.server.on(RPC_CALL, self.on_rpc)
 
         # register http handler
-        task.node.http.add_post('/rpc/{method}', self.http_rpc_handler)
+        task.node.server.add_post('/rpc/{method}', self.http_rpc_handler)
 
     def get_method(self, method: str) -> callable:
         if method not in self.methods:
@@ -28,18 +28,18 @@ class RpcComponent():
 
     async def call(self, method, args):
         rpc_func = self.get_method(method)
-        result = await typed_async_call(rpc_func, args)
+        result, _ = await typed_async_call(rpc_func, args)
         return result
 
     async def on_rpc(self, conn, method, args, nonce):
         try:
             rpc_func = self.get_method(method)
 
-            result = await typed_async_call(rpc_func, args)
-            result_type = get_return_type(rpc_func)
+            result, result_type = await typed_async_call(rpc_func, args)
 
             await conn.send({
                 'type': RPC_RESULT,
+                'id': self.task.id,
                 'nonce': nonce,
                 'method': method,
                 'args': args,
@@ -51,6 +51,7 @@ class RpcComponent():
             traceback.print_exc()
             await conn.send({
                 'type': RPC_ERROR,
+                'id': self.task.id,
                 'nonce': nonce,
                 'method': method,
                 'args': args,
@@ -59,14 +60,24 @@ class RpcComponent():
 
     async def http_rpc_handler(self, req):
         try:
-            args = await req.json()
+            call = await req.json()
+            args = call.get('args', {})
             method = req.match_info['method']
             result = await self.call(method, args)
-            return web.json_response(result)
+            return web.json_response({
+                'success': True,
+                'result': result,
+            })
         except Exception as e:
             print('HTTP RPC Error:')
             traceback.print_exc()
-            return web.json_response({'error': str(e)}, status=400)
+            return web.json_response(
+                {
+                    'success': False,
+                    'error': str(e),
+                },
+                status=400
+            )
 
 
 class RpcError(RuntimeError):
